
import io
from setuptools import find_packages, setup

setup(
	name="qubitmapping",
	version='0.1.1',
	description='initial qubit mapping picked randomly',
	author='Yongsoo Hwang',
	install_requires=[],
	packages=find_packages(),
	zip_safe=False,
	python_requires='>=3'
	)